@@ -12,7 +12,7 @@ use Validation::Class::Util '!has';
 use Hash::Flatten ();
 use Carp 'confess';
 
-# VERSION
+our $VERSION = '7.900006'; # VERSION
 
 use base 'Validation::Class::Mapping';
 
@@ -54,14 +54,4 @@ sub add {
 
 }
 
-sub flatten {
-
-    my ($self) = @_;
-
-    return Validation::Class::Mapping->new(
-        Hash::Flatten::flatten($self->hash)
-    );
-
-}
-
 1;
